@@ -12,17 +12,16 @@
 #' @param name A string of the name (without the extension) for the flob.
 #' If "" (the default) then the original file name is used.
 #' @return A named flob of the file.
-#' @seealso \code{\link{flobr}}
+#' @seealso [flobr()]
 #' @examples
 #' path <- system.file("extdata", "flobr.pdf", package = "flobr")
 #' flob <- flob(path)
 #' flob
 #' @export
 flob <- function(path, name = "") {
-  check_string(path)
-  check_string(name)
-
-  if (!file.exists(path)) stop("file '", path, "' does not exist", call. = FALSE)
+  chk_string(path)
+  chk_file(path)
+  chk_string(name)
 
   n <- file.info(path)$size
   flob <- readBin(path, what = "integer", n = n, endian = "little")
@@ -44,17 +43,20 @@ flob <- function(path, name = "") {
 
 #' Unflob to File
 #'
-#' Converts a \code{\link{flob}} back to its original file format.
+#' Converts a [flob()] back to its original file format.
 #'
-#' If path ends with a file separator then the name and extension of the flob is added.
-#' If the flob is an older flob that was not saved with a name then it is named 'file'.
+#' If path ends with a file separator then the name and extension
+#' of the flob is added.
+#' If the flob is an older flob that was not saved with a name then
+#' it is named 'file'.
 #'
-#' If path ends with a file name without an extension then the extension of the flob
+#' If path ends with a file name without an extension then the
+#' extension of the flob
 #' is automatically added.
 #' Alternatively if path also includes an extension
 #' then it must match the flob's extension.
 #'
-#' @param flob The \code{\link{flob}} to save to file.
+#' @param flob The [flob()] to save to file.
 #' @param dir A string of the path to the directory to save the file in.
 #' @param name A string of the name (without the extension) for the file.
 #' If "" (the default) then the original file name is used.
@@ -65,10 +67,10 @@ flob <- function(path, name = "") {
 #' @examples
 #' unflob(flob_obj, tempdir())
 unflob <- function(flob, dir = ".", name = "", ext = "") {
-  check_flob(flob, old = TRUE)
-  check_string(dir)
-  check_string(name)
-  check_string(ext)
+  chk_flob(flob, old = TRUE)
+  chk_string(dir)
+  chk_string(name)
+  chk_string(ext)
 
   flob <- unlist(flob)
   flob <- unserialize(flob)
@@ -76,8 +78,8 @@ unflob <- function(flob, dir = ".", name = "", ext = "") {
 
   flob <- unlist(flob)
 
-  if(identical(name, "")) name <- file(names)
-  if(identical(ext, "")) ext <- ext(names)
+  if (identical(name, "")) name <- file(names)
+  if (identical(ext, "")) ext <- ext(names)
 
   path <- file.path(dir, paste(name, ext, sep = "."))
 
